Module arguments

Module arguments 

Module for argument parsing

This module provides the argument parsing infrastructure for main.rs. This module is different from all the rest of the library part of this crate as it is the only thing that is not downstream from lib::run, but is seperately called. Therefore it’s only really useful if you run quicklatex as a standalone program, and not in it’s library use.

Structs

Arguments
All the arguments currently supported by the CLI program

Functions

parse_args
Parses the provided arguments